pub enum PlayerMode {
Through,
Replace,
Filter,
Sidechain,
SelfClocked,
}Expand description
How a chain device combines its output with the events flowing through it.
Variants
Through
Pass input through and append generated events.
Replace
Drop input and emit only generated events.
Filter
Filter input by lane, dropping matched events.
Sidechain
Route input while generating side events without merging them.
SelfClocked
Drop input and emit self-clocked generated events.
Implementations
Sourceimpl PlayerMode
impl PlayerMode
Sourcepub fn wire_label(self) -> &'static str
pub fn wire_label(self) -> &'static str
Returns the stable wire label for this mode.
Examples
use sim_lib_music_core::PlayerMode;
assert_eq!(PlayerMode::Through.wire_label(), "through");
assert_eq!(PlayerMode::SelfClocked.wire_label(), "self_clocked");Trait Implementations
Sourceimpl Clone for PlayerMode
impl Clone for PlayerMode
Sourcefn clone(&self) -> PlayerMode
fn clone(&self) -> PlayerMode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PlayerMode
Sourceimpl Debug for PlayerMode
impl Debug for PlayerMode
impl Eq for PlayerMode
Sourceimpl Hash for PlayerMode
impl Hash for PlayerMode
Sourceimpl Ord for PlayerMode
impl Ord for PlayerMode
Sourcefn cmp(&self, other: &PlayerMode) -> Ordering
fn cmp(&self, other: &PlayerMode) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PlayerMode
impl PartialEq for PlayerMode
Sourceimpl PartialOrd for PlayerMode
impl PartialOrd for PlayerMode
impl StructuralPartialEq for PlayerMode