pub struct ChainTraceRecord {
pub sequence: u64,
pub device_id: PlayerDeviceId,
pub action: TraceAction,
pub event: PlayEvent,
pub detail: String,
}Expand description
A single trace record describing one action in a player chain.
Fields
sequence: u64Monotonic sequence number ordering records within a trace.
device_id: PlayerDeviceIdThe device that produced or handled the event.
action: TraceActionThe action taken on the event.
event: PlayEventThe event the action applied to.
detail: StringHuman-readable detail about the action.
Implementations
Sourceimpl ChainTraceRecord
impl ChainTraceRecord
Sourcepub fn new(
sequence: u64,
device_id: PlayerDeviceId,
action: TraceAction,
event: PlayEvent,
detail: impl Into<String>,
) -> Self
pub fn new( sequence: u64, device_id: PlayerDeviceId, action: TraceAction, event: PlayEvent, detail: impl Into<String>, ) -> Self
Builds a trace record from its fields, converting detail into a string.