pub struct MemoryPerformanceSource { /* private fields */ }Expand description
An in-memory PerformanceSource holding state and an optional capture.
Implementations
Sourceimpl MemoryPerformanceSource
impl MemoryPerformanceSource
Sourcepub fn new(source_id: Symbol, channel: Channel) -> Self
pub fn new(source_id: Symbol, channel: Channel) -> Self
Creates an unbound source with the given id and default channel.
Sourcepub fn state(&self) -> &PerformanceSourceState
pub fn state(&self) -> &PerformanceSourceState
Returns a shared reference to the source’s state.
Sourcepub fn state_mut(&mut self) -> &mut PerformanceSourceState
pub fn state_mut(&mut self) -> &mut PerformanceSourceState
Returns a mutable reference to the source’s state.
Sourcepub fn set_octave_shift(&mut self, octave_shift: i8)
pub fn set_octave_shift(&mut self, octave_shift: i8)
Sets the octave shift applied to incoming pitches.
Sourcepub fn set_transpose(&mut self, transpose: i8)
pub fn set_transpose(&mut self, transpose: i8)
Sets the semitone transpose applied to incoming pitches.
Sourcepub fn set_scale_lock(&mut self, scale_lock: Option<ScaleLock>)
pub fn set_scale_lock(&mut self, scale_lock: Option<ScaleLock>)
Sets or clears the scale lock applied to incoming pitches.